@@ -42,7 +42,7 @@ from NaroNet.BioInsights.Pheno_Neigh_Info import topk_confident_patches
 from NaroNet.BioInsights.Pheno_Neigh_Info import extract_topk_patches_from_cohort
 from NaroNet.BioInsights.Pheno_Neigh_Info import save_heatMapMarker_and_barplot
 from NaroNet.BioInsights.Pheno_Neigh_Info import obtain_neighborhood_composition
-from NaroNet.BioInsights.Pheno_Neigh_Info import select_patches_from_cohort
+from NaroNet.BioInsights.Pheno_Neigh_Info import select_patches_from_cohort, visualize_tsne_phenotypes
 from NaroNet.BioInsights.Cell_type_abundance import obtain_celltype_abundance_per_patient
 from NaroNet.BioInsights.Cell_type_abundance import save_celltype_abundance_per_patient
 from NaroNet.BioInsights.Differential_abundance_analysis import differential_abundance_analysis
@@ -323,7 +323,11 @@ class NaroNet_dataset(torch.utils.data.Dataset):
                                   'dataAugmentationPerc':dataAUG})
 
         # Load and augment data
-        data_loaded = parallel_process_v01(dict_gath_dat,self.gatherOneDataAugment_,use_kwargs=True,n_jobs=12,front_num=0,desc='Load data')
+        if args.args['NaroNet_n_workers']==1:
+            front_num = 1
+        else:
+            front_num = 0
+        data_loaded = parallel_process_v01(dict_gath_dat,self.gatherOneDataAugment_,use_kwargs=True,n_jobs=args.args['NaroNet_n_workers'],front_num=front_num,desc='Load data')
 
         # Unmount data to create dataset
         num_nodes=[]
@@ -984,6 +988,8 @@ class NaroNet_dataset(torch.utils.data.Dataset):
         if len([i for i in os.listdir(self.bioInsights_dir_cell_types_Neigh) if 'Interactivity' in i])>0 and False:
             return
 
+        visualize_tsne_phenotypes(self, IndexAndClass,clusters)
+
         CropConfPheno, CropConfTissueComm, TissueArea_Conf = select_patches_from_cohort(self,IndexAndClass,clusters)                 
         
         Channels, Marker_Names = utilz.load_channels(self.root+'Raw_Data/')
@@ -1006,7 +1012,7 @@ class NaroNet_dataset(torch.utils.data.Dataset):
     
         # Obtain Neigh-to-Pheno, and Area-to-Neigh heatmap.
         for ClusteringTrheshold in [0,90]:
-            Area_to_Neighborhood_to_Phenotype(self,clusters,IndexAndClass,ClusteringTrheshold)
+            Area_to_Neighborhood_to_Phenotype(self,clusters,IndexAndClass,ClusteringTrheshold)             
 
         # Obtain cell-types examples
         self.ObtainPhenoExamples(IndexAndClass,clusters,[25,95])                
