@@ -2,37 +2,76 @@ import torch
 import numpy as np
 import torch
 import torch.nn.functional as F
+
 def calc_contrast_loss(features,assignment_orig,device):
 
     # Use a batch size of 1000
-    nbatch = 10000
-    sel_vals = torch.randint(0,features.shape[0],(nbatch,1))
+    nbatch = max(min(10,assignment_orig.shape[0]),assignment_orig.shape[1])
 
     # Calculate feature similarities
-    features = F.normalize(features[sel_vals].squeeze(), dim=1)
-    features = torch.matmul(features, features.T)
-
-    # Find top-1
-    features[torch.eye(features.shape[0], dtype=torch.bool).to(device)] = 0
-    top_elem = features.topk(1,1)[1]
-    #low_elem = features.topk(1,1,largest=False)[1]
-
-    # Calculate assignment similarities  
-    assignment = assignment_orig[sel_vals].squeeze().clone()
-    bound = assignment.max(1,True)[0]
-    assignment[assignment != bound] = 0  # set the values i want to keep to 1
-    assignment[assignment == bound] = 1            
-
-    # Contrast 
+    features = F.normalize(features.squeeze(), dim=1)    
     temp = 0.07
-    positives = torch.exp((assignment*assignment[top_elem.squeeze(),:]).sum(1)/temp)
-    #negatives = torch.exp((assignment*assignment[torch.randint(0,assignment.shape[0],(assignment.shape[0],1)).squeeze(),:]).sum(1)/temp)
 
-    # # Accuracy
-    # pos = torch.eq(assignment.argmax(1),assignment[top_elem.squeeze(),:].argmax(1)).sum()/assignment.shape[0]
-    # neg = torch.eq(assignment.argmax(1),assignment[low_elem.squeeze(),:].argmax(1)).sum()/assignment.shape[0]    
+    loss = 0
+    for ph in range(assignment_orig.shape[1]):
+        sel_vals = assignment_orig[:,ph].topk(nbatch,0)[1]       
+        feats = torch.matmul(features[sel_vals], features.T)        
+        top_elem = (feats.topk(100,1)[1]).reshape(100*nbatch)
+        assignment = assignment_orig[sel_vals][top_elem]
+        positives = torch.exp((torch.matmul(assignment,assignment.T)/temp))
+        loss += -torch.log(positives).mean()*temp
+
+    return loss/assignment_orig.shape[1]
+
+
+# def calc_contrast_loss(features,assignment_orig,device):
+
+#     # Use a batch size of 1000
+#     nbatch = max(min(5,assignment_orig.shape[0]),assignment_orig.shape[1])
+#     sel_vals = assignment_orig.topk(nbatch,0)[1].reshape(nbatch*assignment_orig.shape[1])
+
+#     # Calculate feature similarities
+#     features = F.normalize(features[sel_vals].squeeze(), dim=1)
+#     features = torch.matmul(features, features.T)
+ 
+#     # Find top-1
+#     features[torch.eye(features.shape[0], dtype=torch.bool).to(device)] = 0
+#     top_elem = features.topk(1,1)[1]
+#     #low_elem = features.topk(1,1,largest=False)[1]
+
+#     # Calculate assignment similarities  
+#     assignment = assignment_orig[sel_vals].squeeze().clone()
+#     bound = assignment.max(1,True)[0]
+#     assignment[assignment != bound] = 0  # set the values i want to keep to 1
+#     # assignment[assignment == bound] = 1            
+
+#     # Contrast 
+#     temp = 0.07
+#     positives = torch.exp((assignment*assignment[top_elem.squeeze(),:]).sum(1)/temp)
+#     #negatives = torch.exp((assignment*assignment[torch.randint(0,assignment.shape[0],(assignment.shape[0],1)).squeeze(),:]).sum(1)/temp)
+
+#     # # Accuracy
+#     # pos = torch.eq(assignment.argmax(1),assignment[top_elem.squeeze(),:].argmax(1)).sum()/assignment.shape[0]
+#     # neg = torch.eq(assignment.argmax(1),assignment[low_elem.squeeze(),:].argmax(1)).sum()/assignment.shape[0]    
     
-    return -torch.log(positives).mean()*temp
+#     return -torch.log(positives).mean()*temp
+
+# def calc_contrast_loss(features,assignment_orig,device):
+
+#     # Use a batch size of 1000
+#     nbatch = max(min(int(assignment_orig.shape[0]/assignment_orig.shape[1]*0.001),assignment_orig.shape[0]),assignment_orig.shape[1])
+
+#     features = F.normalize(features.squeeze(), dim=1)
+    
+#     # Calculate entropy loss
+#     loss = 0
+#     for ph in range(assignment_orig.shape[1]):
+
+#         sel_vals = assignment_orig[:,ph].topk(nbatch,0)[1]        
+                        
+#         loss += -torch.log(torch.exp(torch.matmul(features[sel_vals], features[sel_vals].T)/0.07)).mean()
+   
+#     return loss/assignment_orig.shape[1]
 
 def calc_patch_ent(s,device):    
     return ((-s/s.sum(dim=-1,keepdim=True) * torch.log(s/s.sum(dim=-1,keepdim=True) + 1e-15)).sum(dim=-1)/torch.log(torch.tensor(s.shape[1],dtype=torch.float32,device=device))).mean()   
@@ -40,7 +79,7 @@ def calc_patch_ent(s,device):
 def patch_contrast_entropy(x, s, num_nodes, device):
     
     # Calculate contrast acc        
-    contrast_loss = calc_contrast_loss(torch.cat([x[i,:num_nodes[i],:] for i in range(s.shape[0])]), torch.cat([s[i,:num_nodes[i],:] for i in range(s.shape[0])]),device)                     
+    contrast_loss = calc_contrast_loss(torch.cat([x[i,:num_nodes[i],:] for i in range(s.shape[0])]), torch.cat([s[i,:num_nodes[i],:] for i in range(s.shape[0])]),device)          
     
     # Calculate Patch Entropy
     PatchEntropy_loss = calc_patch_ent(torch.cat([s[i,:num_nodes[i],:] for i in range(s.shape[0])]),device)                     
