@@ -139,16 +139,26 @@ class SimCLR(object):
         return logits, labels
 
     def train(self, train_loader):
-
+    
         scaler = GradScaler(enabled=True)
 
         # save config file
         save_config_file(self.writer.log_dir, self.args)
 
+        # Train from previous checkpoint
+        text_files = [f for f in os.listdir(self.model_dir) if f.endswith('.tar')]        
+        if len(text_files)>0:
+            text_files.sort()
+            self.model.load_state_dict(torch.load(os.path.join(self.model_dir, text_files[-1])))
+            self.model.train()
+            done_epochs = len(text_files)*self.args['PCL_Epochs']/10
+        else:
+            done_epochs = 0
+
         n_iter = 0
         logging.info(f"Start SimCLR training for {self.args['PCL_Epochs']} epochs.")        
 
-        for epoch_counter in tqdm(range(self.args['PCL_Epochs'])):
+        for epoch_counter in tqdm(range(self.args['PCL_Epochs']),initial=int(done_epochs)):
             for images in train_loader:
                 images[0] = torch.cat(torch.tensor_split(images[0], images[0].shape[0]),1).squeeze()
                 images[1] = torch.cat(torch.tensor_split(images[1], images[1].shape[0]),1).squeeze()
@@ -301,7 +311,7 @@ class SimCLR(object):
         features_idx = np.concatenate(features_idx,axis=0)        
 
         # Show batch effect        
-        # visualize_batch_effect_Ph(out_dir,features,features_idx,0)
+        visualize_batch_effect_Ph(out_dir,features,features_idx,0)
 
         # Cluster image 
         visualize_using_clustering_ALL(self, out_dir, features, features_idx, patch_images)
